@@ -43,11 +43,17 @@ or
 
   SALSA_TOKEN_FILE=~/.dpt.conf
 
-If you choose to link another file, it must contain a line with something like:
+If you choose to link another file using SALSA_TOKEN_FILE, it must contain a
+line with one of (no differences):
 
   <anything>SALSA_PRIVATE_TOKEN=xxxx
   <anything>SALSA_TOKEN=xxxx
 
+This allows for example to use dpt(1) configuration file (~/.dpt.conf) which
+contains:
+
+  DPT_SALSA_PRIVATE_TOKEN=abcdefghi
+
 =head1 COMMANDS
 
 =head2 Managing users and groups
@@ -145,6 +151,14 @@ exists, update local repo.
   salsa --group js-team co node-mongodb
   salsa co js-team/node-mongodb
 
+You can clone more than one repository or all repositories of a group or a
+user:
+
+  salsa --user yadd co devscripts autodep8
+  salsa co yadd/devscripts js-team/npm
+  salsa --group js-team co --all           # All js-team repos
+  salsa co --all                           # All your repos
+
 =item B<create_repo>
 
 Create public empty project. If C<--group>/C<--group-id> is set, project is
@@ -187,7 +201,7 @@ B<--user>/B<--user-id>, else it is searched in current user namespace.
 
 =item B<ls> or B<list_repos>
 
-Shows project owned by user or group. If Second
+Shows projects owned by user or group. If second
 argument exists, search only matching projects
 
   salsa --group js-team list_repos
@@ -339,7 +353,7 @@ errors, set B<--verbose>.
 
 =item B<update_safe>
 
-Launch B<check_repo> an ask before launching B<update_repo> (unless B<--yes>).
+Launch B<check_repo> and ask before launching B<update_repo> (unless B<--yes>).
 
   salsa --user yadd --tagpending --kgb --irc=devscripts update_safe test
   salsa --group js-team update_safe --all
@@ -419,7 +433,7 @@ Team to use. Use C<salsa search_group name> to find it.
 C<.devscripts> value: B<SALSA_GROUP>
 
 Be careful when you use B<SALSA_GROUP> in your C<.devscripts> file. Every
-B<salsa> commands will be executed in group space, for example if you want to
+B<salsa> command will be executed in group space, for example if you want to
 propose a little change in a project using B<salsa fork> + B<salsa mr>, this
 "fork" will be done in group space unless you set a B<--user>/B<--user-id>.
 Prefer to use an alias in your C<.bashrc> file. Example:
@@ -439,7 +453,7 @@ Group id to use. Use C<salsa search_group name> to find it.
 C<.devscripts> value: B<SALSA_GROUP_ID>
 
 Be careful when you use B<SALSA_GROUP_ID> in your C<.devscripts> file. Every
-B<salsa> commands will be executed in group space, for example if you want to
+B<salsa> command will be executed in group space, for example if you want to
 propose a little change in a project using B<salsa fork> + B<salsa mr>, this
 "fork" will be done in group space unless you set a B<--user>/B<--user-id>.
 Prefer to use an alias in your C<.bashrc> file. Example:
@@ -543,7 +557,7 @@ C<.devscripts> value: B<SALSA_DESC> (yes/no)
 =item B<--desc-pattern>
 
 Repo description pattern. Default to "Debian package %p". "%p" is replaced by
-repo name, while %P is replaced by repo name given in command (may contains
+repo name, while "%P" is replaced by repo name given in command (may contains
 full path).
 
 C<.devscripts> value: B<SALSA_DESC_PATTERN>
@@ -610,7 +624,7 @@ C<.devscripts> value: B<SALSA_IRKER_HOST>
 
 =item B<--irker-port>
 
-Irker host. Default: empty (default value)
+Irker port. Default: empty (default value)
 
 C<.devscripts> value: B<SALSA_IRKER_PORT>
 
@@ -620,6 +634,22 @@ Enable, ignore or disable KGB webhook.
 
 C<.devscripts> value: B<SALSA_KGB> (yes/ignore/no, default: ignore)
 
+=item B<--kgb-options>
+
+List of KGB enabled options (comma separated). Default: issues_events,
+merge_requests_events, note_events, pipeline_events, push_events,
+tag_push_events, wiki_page_events
+
+  $ salsa update_safe debian/devscripts --kgb --irc-channel devscripts \
+    --kgb-options 'merge_requests_events,issues_events,enable_ssl_verification'
+
+List of available options: confidential_comments_events,
+confidential_issues_events, confidential_note_events, enable_ssl_verification,
+issues_events, job_events, merge_requests_events, note_events, pipeline_events,
+tag_push_events, wiki_page_events
+
+C<.devscripts> value: B<SALSA_KGB_OPTIONS>
+
 =item B<--no-fail>
 
 Don't stop on error when using B<update_repo> with B<--all>.
